import QtQuick 1.1
import qb.components 1.0
import qb.base 1.0
import "temperatureLogger.js" as TemperatureLoggerJS


App {
	id: temperatureLoggerApp

	// These are the URL's for the QML resources from which our widgets will be instantiated.
	// By making them a URL type property they will automatically be converted to full paths,
	// preventing problems when passing them around to code that comes from a different path.

	property url thumbnailIcon: "./drawables/buienradar.png"
	property TemperatureLoggerScreen temperatureLoggerScreen
	property url trayUrl2 : "TemperatureLoggerTray.qml";
	property string timeStr

	property variant arycurrentTemp : []
	property variant arycurrentSetpoint : []
	property int nowlinexcoordinate : 20
	property string nowleftlabel : "--"
	property string nowrightlabel : "--"

	QtObject {
		id: p

		property url temperatureLoggerScreenUrl : "TemperatureLoggerScreen.qml"
	}

	
	function init() {
		registry.registerWidget("screen", p.temperatureLoggerScreenUrl, this, "temperatureLoggerScreen");
		registry.registerWidget("systrayIcon", trayUrl2, this, "temperatureLoggerTray");
	}



	function updateActualAndProgramTemp() {
		var xmlhttpt = new XMLHttpRequest();
		xmlhttpt.onreadystatechange = function() {

			nowleftlabel = xmlhttpt.readyState;
			if  ( xmlhttpt.readyState == 4 ) {
				nowrightlabel = xmlhttpt.status;

				
				if  ( xmlhttpt.status == 200  ) {

					nowleftlabel = xmlhttpt.readyState;
					nowrightlabel = xmlhttpt.status;

						//calculate index in array

				  	var datum = new Date();
	  				var hour = datum.getHours();
         				var min  = datum.getMinutes();
					var index = (hour * 6) + Math.round(min /10);

						//read temp readings

					var txtStat = xmlhttpt.responseText;
					var idxcurrentSetpoint = txtStat.indexOf("currentSetpoint");
					var idxcurrentTemp = txtStat.indexOf("currentTemp");
					var currentSetpoint = -12 + (parseInt(txtStat.substring(18 + idxcurrentSetpoint, 22 + idxcurrentSetpoint)) / 100);
					var currentTemp = -12 + (parseInt(txtStat.substring(14 + idxcurrentTemp , 18 + idxcurrentTemp)) / 100);

						//store values in arrays

					arycurrentTemp = TemperatureLoggerJS.addReadingTemp(arycurrentTemp , index, currentTemp);
					arycurrentSetpoint = TemperatureLoggerJS.addReadingSetpoint(arycurrentSetpoint , index, currentSetpoint);

						//update positioning line and labels on screen

					nowlinexcoordinate = (694 * index / 144) + 25;
					var dag = datum.getDate();
					var maand = datum.getMonth();
					nowleftlabel = dag + "-" + (maand+1);

					datum.setDate(datum.getDate() - 1);
					dag = datum.getDate();
					maand = datum.getMonth();
					nowrightlabel = dag + "-" + (maand+1);

	     			}
 		  	}
		}
		xmlhttpt.open("GET", "http://127.0.0.1:10080/happ_thermstat?action=getThermostatInfo", true );
		xmlhttpt.send();
	}



	Timer {
		id: datetimeTimertl
		interval: 300000
		triggeredOnStart: true
		running: true
		repeat: true
		onTriggered: {
			updateActualAndProgramTemp();
		}
	}

}
